class WallboxError(Exception):

    def __init__(self, message=None, kind=None, field=None, key=None):
        self.kind = kind
        self.field = field
        self.message = message or "An error occurred"
        self.key = key
        super().__init__(self.__str__())

    def __str__(self):
        details = []
        if self.kind:
            details.append(f"Kind: {self.kind}")
        if self.field:
            details.append(f"Field: {self.field}")
        if self.key:
            details.append(f"URI: {self.key}")
        details.append(f"Message: {self.message}")
        return " | ".join(details)



from .atmel import AtmelErrorGetResponse
from .auth_key import (
    AuthKeyInitRequest,
    AuthKeyInitResponse,
    AuthKeyResponseRequest,
    AuthKeyResponseResponse,
)
from .auth_password import AuthPasswordRequest, AuthPasswordResponse
from .config_load import ConfigLoadSetRequest, ConfigLoadResponse
from .config_network import (
    ConfigNetworkStatusResponse,
    Wifi,
    Ethernet,
    ConfigNetworkGetResponse,
)
from .config_ocpp import ConfigOCCPData
from .helpers import Color, ColorFull
from .info import (
    InfoSerialGetResponse,
    ESP,
    Atmel,
    InfoFirmwaresGetResponse,
)
from .message import ErrorData, MessageRequest, MessageResponse
from .rfid import (
    RfidGetResponse,
    RfidScanRequest,
    RfidData,
    RfidDeleteRequest,
)
from .setup import SetupData
from .transaction import (
    TransactionEntry,
    TransactionStopResponse,
    TransactionStartRequest,
)
from .user import (
    User,
    UserData,
    UserAddRequest,
    UserDeleteRequest,
)
from .util import (
    UtilRestartData,
    UtilAtmelRestartResponse,
    FactoryResetResponse,
)

__all__ = [
    "AtmelErrorGetResponse",
    "AuthKeyInitRequest",
    "AuthKeyInitResponse",
    "AuthKeyResponseRequest",
    "AuthKeyResponseResponse",
    "AuthPasswordRequest",
    "AuthPasswordResponse",
    "ConfigLoadSetRequest",
    "ConfigLoadResponse",
    "ConfigNetworkStatusResponse",
    "Wifi",
    "Ethernet",
    "ConfigNetworkGetResponse",
    "ConfigOCCPData",
    "Color",
    "ColorFull",
    "InfoSerialGetResponse",
    "ESP",
    "Atmel",
    "InfoFirmwaresGetResponse",
    "ErrorData",
    "MessageRequest",
    "MessageResponse",
    "RfidGetResponse",
    "RfidScanRequest",
    "RfidData",
    "RfidDeleteRequest",
    "SetupData",
    "TransactionEntry",
    "TransactionStopResponse",
    "TransactionStartRequest",
    "User",
    "UserData",
    "UserAddRequest",
    "UserDeleteRequest",
    "UtilRestartData",
    "UtilAtmelRestartResponse",
    "FactoryResetResponse",
]



from dataclasses import dataclass

from .helpers import Color, ColorFull


@dataclass
class User:
    name: str
    admin: bool
    color: Color
    id: int
    publicKey: list[int] = None


@dataclass
class UserData:
    id: int
    user: User


@dataclass
class UserAddRequest:
    name: str
    password: str
    color: ColorFull
    admin: bool


@dataclass
class UserDeleteRequest:
    id: int



from dataclasses import dataclass, field
from typing import List

from cbor2 import CBORTag


@dataclass
class TransactionEntry:
    ocppCpState: str
    connectionState: str
    currentChargeRate: int
    authorizationState: str
    secondsSinceChargeStart: int
    currentTransactionEnergy: int


@dataclass
class TransactionStopResponse:
    energy: int
    endTime: str
    startTime: str
    startedBy: list[int]
    sessionNumber: int


@dataclass
class TransactionStartRequest:
    tag_id: List[int] = field(default_factory=list)

    def to_array(self):
        return self.tag_id



from dataclasses import dataclass


@dataclass
class ConfigNetworkStatusResponse:
    wlan: str
    ethernet: str


@dataclass
class Wifi:
    mode: str
    ssid: str
    password: str


@dataclass
class Ethernet:
    mode: str


@dataclass
class ConfigNetworkGetResponse:
    wifi: Wifi
    ethernet: Ethernet
